colour.models.dataset.aces_rgb_idt Module — Colour 0.3.0 documentation

# colour.models.dataset.aces_rgb_idt Module

## ACES RGB Colourspace - Input Device Transform Dataset

Defines the ACES RGB colourspace Input Device Transform dataset.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.oscars.org/science-technology/council/projects/aces.html (Last accessed 24 February 2014)

[2] | http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf (Last accessed 24 February 2014)

`colour.models.dataset.aces_rgb_idt.` `ACES_RICD` = <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102e06e50>

  ACES Reference Input Capture Device spectral sensitivities.

  ACES_RICD : RGB_ColourMatchingFunctions